@@ -13,12 +13,14 @@ class _DDLOptions(StrEnum):
 
 
 class _Config(StrEnum):
-    PROPERTIES_BD_GROUP = 'properties_bd_group'
     DDL_AUTO_VALUE = 'ddl_auto_value'
     NAME_SHCEMA_MODULE = 'name_shcema_module'
+    PROPERTIES_BD_GROUP = 'properties_bd_group'
 
 
 class _Properties(StrEnum):
+    ASC = 'asc'
+    DESC = 'desc'
     PATH_MODULE_SCHEMA = 'path_module_schema'
     DDL_AUTO = 'ddl_auto'
     URL_CONNECTION = 'url_connection'
